@@ -85,7 +85,7 @@ fn into_buffer(values: Vec<Value>, column_def: Column) -> AnyColumnBuffer {
 				.collect(),
 		),
 		Str => {
-			let mut col = TextColumn::new(100, 1);
+			let mut col = TextColumn::new(255, values.len());
 			values.into_iter().enumerate().for_each(|(index, value)| {
 				let text: String = value.cast().unwrap();
 				col.append(index, Some(text.as_bytes()))
